import Qt 4.7

Item
{
    property variant target
    objectName:	"scrollBar"
    id:scrollBar
    width: backUp.width
    visible: track.height > thumb.height && target.contentHeight > 0

	function calculateThumbHeight()
	{
		var tempHeight = 0;
		if(target.contentHeight > 0)
			tempHeight = (target.height / target.contentHeight) * track.height;
		return tempHeight > 16 ? tempHeight : 16;
	}
	function getTrackSize()
	{
		return track.height;
	}
	function calculateThumbPosition()
	{
		var thumbPos = 0;
		if(target.contentHeight > 0)
			thumbPos = (target.contentY * getTrackSize()) / target.contentHeight;
		return thumbPos;
	}
	function calculateContentPosition()
	{
		if(target.contentHeight == 0)
			return 0;
		thumb.height = calculateThumbHeight(); 
		var temp = (thumb.y / getTrackSize()) * target.contentHeight;
		return temp;
	}
	
    Item
    {
        anchors.fill: parent

        Timer
        {
            property int scrollAmount
            id: scrollRepeater
            repeat: true
            interval: 20
            onTriggered:
            {
                target.contentY = Math.max(0, Math.min(target.contentY + scrollAmount, target.contentHeight - target.height));
            }
        }

        Image
        {
            id: backUp
            source: "../images/widgets/scroll_up.png";
        }
        Image
        {
            id: backDown
            source: "../images/widgets/scroll_down.png";
            anchors.bottom: parent.bottom;
        }
        Image
        {
            id: backFiller
            source: "../images/widgets/scroll_filler.png";
            anchors.top: backUp.bottom;
            anchors.bottom: backDown.top;
            fillMode: Image.TileVertically
        }

        Item
        {
            id: track
            anchors {top: parent.top; topMargin: 1; bottom: parent.bottom; leftMargin: 1;}
            width: parent.width

            MouseArea
            {
                anchors.fill: parent
                onPressed:
                {
                    scrollRepeater.scrollAmount = target.height * (mouseY < thumb.y ? -1 : 1)	// scroll by a page
                    scrollRepeater.running = true;
                }
                onReleased:
                {
                    scrollRepeater.running = false;
                }
                Clickable {}
                hoverEnabled : true
            }

            Item
            {
                id:thumb
                height: scrollBar.calculateThumbHeight();                
                width: parent.width
                Image
                {
                    id: thumbUp
                    source: "../images/widgets/thumb_up.png";
                }
                Image
                {
                    id: thumbDown
                    source: "../images/widgets/thumb_down.png";
                    anchors.bottom: parent.bottom;
                }
                Image
                {
                    id: thumbFiller
                    source: "../images/widgets/thumb_filler.png";
                    anchors.top: thumbUp.bottom;
                    anchors.bottom: thumbDown.top;
                    fillMode: Image.TileVertically
                }
                Image
                {
                    id: thumbGrabbers
                    source: "../images/widgets/thumb_grabbers.png";
                    visible: thumbFiller.height >= thumbGrabbers.height
                    anchors.verticalCenter: thumbFiller.verticalCenter;
                    anchors.horizontalCenter: thumbFiller.horizontalCenter;
                }

				Connections
				{
					target: scrollBar.target
					onContentYChanged: {
						if (!mouseArea.drag.active)
						{
							thumb.y = calculateThumbPosition();
						}
					}
					onContentHeightChanged: {
						if (!mouseArea.drag.active)
						{
							thumb.y = calculateThumbPosition();
						}
					}
				}
				
                MouseArea
                {
					id: mouseArea
                    anchors.fill: parent
                    drag.target: parent
                    drag.axis: Drag.YAxis
                    drag.minimumY: 0
                    drag.maximumY: track.height - height
                    hoverEnabled : true

                    Clickable { }
                    onExited: thumb.y = calculateThumbPosition();

					PropertyAnimation {
						 id: dragAnimation
						 target: scrollBar.target
						 properties: "contentY"
						 easing.type: Easing.InOutQuad
						 duration: 30
					}
					
                    onPositionChanged:
                    {
                        if (pressedButtons == Qt.LeftButton)
						{
							dragAnimation.to = scrollBar.calculateContentPosition();
							dragAnimation.start();
						}
                    }
                }
            }
        }
    }
}

