import Qt 4.7
import "../common/widgets" as Widgets
import "../common/EnumHelper.js" as EnumHelper
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/Colors.js" as Colors

Border.BorderedContent
{
    content: fileAdvisor
    property variant context: FileAdvisor

    function getTrustColor()
    {
        return EnumHelper.convert(context, "TrustLevel", {
            "Trusted": "green",
            "Restricted": "yellow",
            "NotTrusted": "red",
            "TrustUnknown": "gray" });
    }

    Widgets.SecondaryWindow
    {
        id: fileAdvisor
        property variant commonFontStyles: Fonts.Common{}
        width: 500
        height: workAreaItem.contentHeight + 29 /* top margin */ + 44 /* bottom margin */
        objectName: "KasperskyFileAdvisor"
        iconImage: "../common/images/file_advisor/ico_file_advisor_16.png"
        caption: context.Localize("WindowTitle")

        property color fillingColor: Colors.grayArea
        property color horizontalSeparatorColor: Colors.grayBorder
        property color horizontalLineColor: Colors.grayBorder

        workArea: Column
        {
            id: mainColumn
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right
            objectName: "MainColumn"
            property real contentHeight: childrenRect.height - (showHideDetails.showDetails ? 0 : moreDetails.height)

            Component
            {
                id: dataRow
                Item
                {
                    id: dataRowItem
                    width: mainColumn.width
                    height: Math.max(labelArea.height, valueArea.height) + 7

                    Item
                    {
                        id: labelArea
                        width: 150
                        height: imageLabel.visible ? imageLabel.height : textLabel.height
                        Widgets.DPIScaler { changeWidth: true }
                        anchors
                        {
                            verticalCenter: parent.verticalCenter
                            left: parent.left
                            leftMargin: 20
                        }

                        Item
                        {
                            id: imageLabel
                            anchors.right: parent.right
                            height: image.height
                            width: image.width
                            visible: typeof(modelData.iconName) != 'undefined'

                            Image
                            {
                                id: image
                                anchors.right: parent.right
                                source: { parent.visible ?
                                    "../common/images/file_advisor/ico_"
                                        + modelData.iconName
                                        + (typeof(modelData.iconModifier) != "undefined" ? "_" + modelData.iconModifier : "")
                                        + "_24"
                                        + (modelData.useColor ? "_" + getTrustColor() : "")
                                        + ".png"
                                    : "" }
                            }
                        }

                        Text
                        {
                            id: textLabel
                            width: parent.width
                            horizontalAlignment: Text.AlignRight
                            elide: Text.ElideRight
                            text: typeof(modelData.name) != 'undefined' ? modelData.name : ""
                            font: fileAdvisor.commonFontStyles.standardCommonTextFont
                            visible: typeof(modelData.name) != 'undefined'
                        }
                    }

                    Item
                    {
                        id: valueArea
                        height: childrenRect.height
                        anchors
                        {
                            verticalCenter: parent.verticalCenter
                            left: labelArea.right
                            leftMargin: 10
                            right: parent.right
                            rightMargin: 20
                        }
                        Text
                        {
                            function getElide(type)
                            {
                                switch (type)
                                {
                                    case "Path": return Text.ElideMiddle;
                                }
                                return Text.ElideNone;
                            }
                            function getWrapMode(type)
                            {
                                switch (type)
                                {
                                    case "Application": return Text.Wrap;
                                    case "DistributionArea": return Text.Wrap;
                                    case "users": return Text.Wrap;
                                }
                                return Text.NoWrap;
                            }
                            function isFontBold(type)
                            {
                                switch (type)
                                {
                                    case "Application":
                                        return true
                                }
                                return false
                            }
                            id: valueText
                            text: modelData.value
                            elide:getElide(modelData.objectName)
                            width: parent.width
                            wrapMode: getWrapMode(modelData.objectName)
                            font: fileAdvisor.commonFontStyles.standardCommonTextFont
                            visible: !actionValue.visible
                            Binding
                            {
                                target: valueText
                                property: "font.bold"
                                value: valueText.isFontBold(modelData.objectName)
                            }
                        }
                        Widgets.Hyperlink
                        {
                            id: actionValue
                            text: modelData.value
                            visible: typeof(modelData.action) != 'undefined'
                        }
                    }
                }
            }

            Item
            {
                Image
                {
                    x: 20
                    y: 17
                    source: "image://fileadvisor/" + FileAdvisor.FilePath
                    asynchronous: true
                }

                height: topDetailsColumn.y + topDetailsColumn.height
                width: parent.width

                Column
                {
                    y: 16
                    id: topDetailsColumn
                    width: parent.width
                    Repeater
                    {
                        delegate: dataRow
                        model: FileAdvisor.BasicInfo
                    }
                }
            }

            Item { width: parent.width; height: 10 }

            Rectangle
            {
                height: 1
                width: parent.width
                color: fileAdvisor.horizontalSeparatorColor
            }

            Rectangle // additonal Details
            {
                width: parent.width
                height: additonalDetailsColumn.height
                color: fileAdvisor.fillingColor
                objectName: "DetailRectangle"

                Column
                {
                    id: additonalDetailsColumn
                    width: parent.width
                    objectName: "DetailColumn"

                    Item { width: parent.width; height: 12 }

                    Item
                    {
                        id: progressArea
                        width: parent.width
                        height: Math.max(progressText.height, progressImage.height) + 10
                        visible: context.KsnQueryState == 0

                        Item
                        {
                            id: progressLabelArea
                            width: 150
                            height: progressImage.height

                            Widgets.Loading48
                            {
                                id: progressImage
                                anchors
                                {
                                    top: parent.top
                                    topMargin: 5
                                    right: parent.right
                                }

                            }
                        }

                        Text
                        {
                            id: progressText
                            anchors
                            {
                                top: parent.top
                                topMargin: 5
                                left: progressLabelArea.right
                                leftMargin: 10
                                right: parent.right
                                rightMargin: 10
                            }
                            text: context.Localize('RequestProgress')
                            font: fileAdvisor.commonFontStyles.standardCommonTextFont
                            wrapMode: Text.Wrap
                        }
                    }

                    Item
                    {
                        id: failedAread
                        width: parent.width
                        height: Math.max(failedImage.height, failedText.height) + 10
                        visible: context.KsnQueryState == 2

                        Item
                        {
                            id: failedLabelArea
                            width: 150
                            height: failedImage.height

                            Image
                            {
                                id: failedImage
                                source: "../common/images/file_advisor/ico_file_unknown_48.png"
                                anchors
                                {
                                    top: parent.top
                                    topMargin: 5
                                    right: parent.right
                                }
                            }
                        }

                        Column
                        {
                            id: failedText
                            spacing: 10
                            anchors
                            {
                                top: parent.top
                                topMargin: 5
                                left: failedLabelArea.right
                                leftMargin: 10
                                right: parent.right
                                rightMargin: 10
                            }

                            Text
                            {
                                text: context.Localize('KsnFailure')
                                font: fileAdvisor.commonFontStyles.standardCommonTextFont
                                width: parent.width
                                wrapMode: Text.Wrap
                            }
                            Text
                            {
                                text: context.KsnFailureText
                                font: fileAdvisor.commonFontStyles.standardCommonTextFont
                                width: parent.width
                                wrapMode: Text.Wrap
                            }
                        }
                    }

                    Repeater
                    {
                        delegate: dataRow
                        model: FileAdvisor.KsnInfo
                        visible: context.KsnQueryState != 0
                    }

                    Item { width: parent.width; height: 4 }

                    Item
                    {
                        id: showHideDetails
                        objectName: "ShowHideDetailsRow"
                        width: parent.width
                        height: showHideDetailsButton.height + 7
                        property bool showDetails: false

                        Widgets.Button
                        {
                            id: showHideDetailsButton
                            objectName: "showHideDetailsButton"
                            anchors.left: parent.left
                            anchors.top: parent.top
                            anchors.leftMargin: 20
                            text: context.Localize(showHideDetails.showDetails ? 'Brief' : 'Details')
                            iconImage: "../images/file_advisor/ico_"
                                + (showHideDetails.showDetails ? "collapse" : "expand")
                                + "_16.png"
                            iconDisabledImage: "../images/file_advisor/ico_expand_16_disabled.png"
                            onClicked: showHideDetails.showDetails = !showHideDetails.showDetails
                            enabled: context.KsnQueryState != 0
                            textfont: fileAdvisor.commonFontStyles.standardCommonTextFont
                            textcolor: "black"
                        }

                        Rectangle
                        {
                            anchors.left: showHideDetailsButton.right
                            anchors.right: parent.right
                            anchors.leftMargin: 10
                            anchors.rightMargin: 10
                            anchors.verticalCenter: showHideDetailsButton.verticalCenter
                            color: fileAdvisor.horizontalLineColor
                            height: 1
                        }
                    }

                    Column
                    {
                        id: moreDetails
                        width: parent.width

                        Repeater
                        {
                            delegate: dataRow
                            model: FileAdvisor.AppearanceInfo
                            visible: FileAdvisor.AppearanceInfo.length != 0;
                        }

                        Item { width: parent.width; height: 12 }
                        Rectangle
                        {
                            anchors.left: moreDetails.left
                            anchors.right: moreDetails.right
                            anchors.leftMargin: 10
                            anchors.rightMargin: 10
                            height: 1
                            color: fileAdvisor.horizontalLineColor
                            visible: FileAdvisor.AppearanceInfo.length != 0;
                        }
                        Item { width: parent.width; height: 14 }

                        Repeater
                        {
                            delegate: dataRow
                            model: FileAdvisor.DetailInfo
                        }

                        Item { width: parent.width; height: 12; visible: lastSeparator.visible }
                        Rectangle
                        {
                            id: lastSeparator
                            anchors.left: moreDetails.left
                            anchors.right: moreDetails.right
                            anchors.leftMargin: 10
                            anchors.rightMargin: 10
                            height: 1
                            color: fileAdvisor.horizontalLineColor
                            visible: FileAdvisor.SecurityInfo.length != 0;
                        }
                        Item { width: parent.width; height: 14; visible: lastSeparator.visible }

                        Repeater
                        {
                            delegate: dataRow
                            model: FileAdvisor.SecurityInfo
                            visible: FileAdvisor.SecurityInfo.length != 0;
                        }
                        Item { width: parent.width; height: 14 }
                    }

                }
            }
        }
        buttonsArea: Item
        {
            objectName: "Bottom"

            Widgets.GrayButton
            {
                id: scanButton
                objectName: "scanButton"
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                text: context.Localize('Scan')
                enabled: context.CanScanForViruses
                onClicked: context.ScanForViruses()
            }

            Widgets.GrayButton
            {
                objectName: "BottomCloseButton"
                anchors.right: parent.right
                anchors.verticalCenter: parent.verticalCenter
                text: context.Localize('CloseButton')
                onClicked: Window.Close()
            }
        }
        Behavior on height
        {
            id: behavior
            enabled: true
            SmoothedAnimation { velocity: 500 }
        }
    }
}
