import Qt 4.7
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper
import "../common/widgets" as Widgets
import "../common/Colors.js" as Colors

Rectangle
{
    id:page
    objectName: "licensePage"

    property variant model : MainWindow.licenseManager
    property variant commonFontStyles: Fonts.Common{}

    function getLicenseImage(object, licenseState)
    {
        return EnumHelper.convert(object, licenseState, {
			"Actual":"../common/images/license/pic_license_normal.png",
			"Invalid":"../common/images/license/pic_license_expired.png",
			"Unknown":"../common/images/license/pic_license_unknown.png",
			"HasWarnings":"../common/images/license/pic_license_normal.png"});
    }

    function getStatusColor(object, licenseState)
    {
        return EnumHelper.convert(object, licenseState, {
            "Actual":Colors.green,
            "Invalid":Colors.red,
            "Unknown":"gray",
            "HasWarnings":Colors.green});
    }

	Image
	{
			id: licenseImage
			source: getLicenseImage(page.model, "ActiveLicenseState");
			anchors.left:parent.left;anchors.leftMargin:30
			anchors.top:parent.top;anchors.topMargin:34
	}

    Component
    {
         id: infoDelegate
         Item
         {
             width:commonItem.width;
             height:commonItem.height
             visible: true;

             Widgets.StaticLabel
             {
                 id:commonItem
                 caption:model.modelData.name
                 value: model.modelData.value
                 captionFont:commonFontStyles.standardCommonTextFont
                 valueFont:commonFontStyles.standardCommonTextFont
                 valueColor:model.modelData.isLicenseState ? page.getStatusColor(page.model, "ActiveLicenseState") : "gray";
                 isWrapMode: false;
                 wrapToBottom: false;
                 visible: !licenseStatus.visible
             }

             Row
             {
                 id: licenseStatus
                 visible: model.modelData.isLicenseNumber
                 spacing: 2
                 Text
                 {
                     text: model.modelData.name
                     font: commonFontStyles.standardCommonTextFont
                 }
                 Widgets.Hyperlink
                 {
                     text: model.modelData.value
                     onClicked: page.model.ShowLicenseInfoDialog()
                 }
             }

             Image
             {
                 id: licenseRemove
                 source: "../common/images/license/Cross_ico.png";
                 anchors.left:commonItem.right; anchors.leftMargin:3
                 anchors.top:commonItem.top; anchors.topMargin:3
                 visible: model.modelData.isLicenseNumber;
                 MouseArea
                 {
                     anchors.fill: parent
                     hoverEnabled: true;
                     onClicked: page.model.DeletePrimaryLicense()
                     Widgets.Clickable {}
                 }
             }
         }
    }
		    
    Flickable
    {
        id:scrollPane
        objectName: "scrollPane"
        anchors.left:licenseImage.right;anchors.leftMargin:28
        anchors.top:licenseImage.top
        anchors.topMargin: 3
        anchors.right:parent.right;
        anchors.bottom: page.bottom;
		clip: true

        contentHeight: choiceBars.height

		Column
		{
			id: choiceBars
			objectName: "choiceBars"
			spacing: 18
			width: parent.width
			height: childrenRect.height

			ListView
		    {
		        id:infoList
		        objectName: "infoList"
		        width: parent.width
		        height: 300
		        model:page.model.LicenseInfo
		        interactive: false
		        delegate:infoDelegate
                spacing: 6
		        onContentHeightChanged: height = contentHeight
		        Component.onCompleted: height = contentHeight
		    }
			function getIconImage(object, licenseState)
		    {
		        return "../common/images/ico_" + EnumHelper.convert(object, licenseState, {
		            "Actual":"info",
		            "Invalid":"danger",
		            "Unknown":"info",
		            "HasWarnings":"warning"}) + "_24.png";
		    }
		    Widgets.ChoiceBar
		    {
				objectName: "activeChoiceBar"
		        visible:model.ShouldShowActiveLicenseBlock
		        shouldShowReserveCode:false
				width: parent.width
		        maxHeight: contentHeight

		        caption:model.ActiveLicenseBlockHeader;
		        captionLeftImage: choiceBars.getIconImage(page.model, "ActiveLicenseState")
		        description:model.ActiveLicenseBlockText;
		        buttonListModel:page.model.ActiveLicenseBlockButtonList
		        model:page.model
		    }
		    Widgets.ChoiceBar
		    {
				objectName: "reserveChoiceBar"
		        visible:model.ShouldShowReserveCodeBlock
		        shouldShowReserveCode:model.ShouldShowReserveCode

				width: parent.width
		        maxHeight:contentHeight

		        caption:model.ReserveCodeBlockHeader;
		        captionLeftImage: choiceBars.getIconImage(page.model, "ReserveCodeState")
		        description:model.ReserveCodeBlockText;
		        buttonListModel:page.model.ReserveCodeBlockButtonList
		        model:page.model
		    }
		}
	}
	
    Widgets.FlickableScrollBar
    {
        id:scrollbar
        target:scrollPane
        anchors.top:parent.top; anchors.topMargin: 5
        anchors.right:parent.right; anchors.rightMargin:5
        anchors.bottom: parent.bottom; anchors.bottomMargin: 5
    }
}
