import Qt 4.7
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/Margins.js" as Margins

Item
{
	anchors.fill: parent
	objectName: "SetPassword"

	property variant context: MainWindow.parentalControl
	property string error: ""
	property variant commonFontStyles: Fonts.Common{}
	property variant isPasswordEntered: false

	function setActiveFocus(delay)
	{
    		newPassword.setActiveFocus(delay);
	}
    
	Component.onCompleted:
	{
		newPassword.focus = true
	}

    Widgets.StandardCaptionText
	{
		id: header
		y: 100
		anchors.horizontalCenter: parent.horizontalCenter
		text: context.Localize("PasswordProtection")
	}

	Text
	{
		id: description
		anchors.top: header.bottom
        anchors.topMargin: Margins.verticalCaptionToCommonText
		anchors.horizontalCenter: parent.horizontalCenter
		horizontalAlignment: Text.AlignHCenter
		width:  parent.width - 300
		text: context.Localize("PasswordProtectionDescription")
		font: commonFontStyles.standardCommonTextFont
		color: "black"
		wrapMode: Text.Wrap
        lineHeight: Margins.commonTextLineHeight
	}


	Widgets.EditBox
	{
		id: newPassword
		objectName: "NewPassword"

		anchors.top: description.bottom
        anchors.topMargin: Margins.verticalCommonTextToWidget
		anchors.left:parent.horizontalCenter
		anchors.leftMargin : -width/2
		anchors.right:confirmation.right

		isPassword: true
		width:  180
		height: 25

		Keys.onPressed:
		{
			if (Qt.Key_Tab == event.key)
			{
				confirmation.setActiveFocus(1);
			}
			else if (Qt.Key_Return == event.key)
			{
				if (text.length)
					confirmation.setActiveFocus(1);
			}
				
		}
	}

	Binding {target: context.PasswordSet; property: "Password"; value: newPassword.text }

	Text
	{
		anchors.verticalCenter: newPassword.verticalCenter
		anchors.right: newPassword.left
		anchors.rightMargin: 6
		text: context.Localize("Password")
		color: "black"
		font: commonFontStyles.standardCommonTextFont
	}

	Widgets.EditBox
	{
		id: confirmation
		objectName: "Confirmation"
		anchors.top: newPassword.bottom
		anchors.topMargin: 12
		anchors.left: newPassword.left
		anchors.right: showPasswordGroupDialogButton.right
		isPassword: true
		height: 25

		Keys.onPressed:
		{
			if (Qt.Key_Tab == event.key)
				createPasswordButton.focus = true;
			else if (Qt.Key_Return == event.key)
			{
				if (newPassword.text.length + text.length)
					createPasswordButton.doAction();
				else
					showPasswordGroupDialogButton.doAction();
			}
		}
	}

	Binding {target: context.PasswordSet; property: "PasswordConfirmation"; value: confirmation.text }

	Text
	{
		anchors.right: confirmation.left
		anchors.rightMargin: 6
		anchors.verticalCenter: confirmation.verticalCenter
		text: context.Localize("Confirm")
		color: "black"
		font: commonFontStyles.standardCommonTextFont
	}

	Widgets.GrayButton
	{
		id: showPasswordGroupDialogButton
		objectName: "SetPasswordGroupButton"
		anchors.top: confirmation.bottom
		anchors.topMargin: 18
		anchors.left : createPasswordButton.right
        anchors.leftMargin : Margins.horizontalBetweenButtons
		text: context.Localize("SkipButton")

		onClicked:
		{
			doAction();
		}
		function doAction()
		{
			context.PasswordSet.IsPasswordSkiped = true
		}
	}

	Widgets.GrayButton
	{
		id: createPasswordButton
		objectName: "CreatePasswordButton"
		anchors.top: showPasswordGroupDialogButton.top
		anchors.left: confirmation.left
		text: context.Localize("Continue")
		enabled: newPassword.text.length > 0

		onClicked:
		{
			doAction();
		}
		function doAction()
		{
			isPasswordEntered = context.PasswordSet.IsPasswordConfirmed

			if (context.PasswordSet.IsPasswordConfirmed)
			{
				error = ""
			}
			else
			{
				error = context.Localize("PasswordNotConfirmed")
			}
		}
	}

	Text
	{
		anchors.top: createPasswordButton.bottom
		anchors.topMargin: 20
		anchors.horizontalCenter: parent.horizontalCenter
		text: error
		font: commonFontStyles.standardCommonTextFont
		color: "red"
	}
}
