import Qt 4.7
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets

Item
{
    id: frontView
	property variant commonFontStyles: Fonts.Common{}
	height: parent.height - y
	objectName: "frontView"
    property int margin: 10

	ScanButton
	{
		id: scanButton
        x: frontView.margin
        y: frontView.margin
		objectName: "ScanButton"
		context: scan.contextScan
		enabled:
		{
			if(contextScan == undefined)
				return false
			if(contextScan.IsRunning && !contextScan.IsStopping)
				return contextScan.CanStop;
			return contextScan.CanStart;
		}
		onClickStart:
		{
			if(!contextScan.IsRunning && contextScan.CanResume)
			{
				askPanel.state = "askResumeScan"
				setBackPosition()
			}
			else
			{
				startScan()
			}
		}
		onClickStop:
		{
			askPanel.state = "askStopScan"
			setBackPosition()
		}
	}

	Item
	{
		objectName: "info"
		anchors.left: scanButton.right
		anchors.leftMargin: 15
		anchors.right: parent.right
        anchors.top: parent.top
        anchors.topMargin: frontView.margin
        anchors.bottom: parent.bottom


		Text
		{
			id:		headerInfo
			text:	scan.scanHeader
			
			font: commonFontStyles.standardBoldSubHeadingFont
		}
		// common specific
		Item
		{
			id:		commonText
			width:	parent.width
			height: column.height
            anchors.top: headerInfo.bottom
            anchors.topMargin: 2

			// Failed specific
			Column
			{
				id:			descriptionForFailedScan
				width:		parent.width
				height:		parent.height
                spacing:	2
                visible:	contextScan.IsFailed;

				Row
				{
					Text{text: contextScan.Localize("SinceTaskFailDescription"); font: commonFontStyles.standardCommonTextFont}
                    Widgets.Hyperlink
                    {
                        text: contextScan.DurationSinceLastStop
                        onClicked: contextScan.ShowScanObjectReport();
                    }
				}
				Text
				{
					text: contextScan.LastError
					font: commonFontStyles.standardCommonTextFont
					wrapMode: 	Text.Wrap
				}
			}
			// NeverRun specific
			Text
			{
				id:			descriptionForNeverRanScan
				width:		parent.width - 20
                anchors.top: parent.top
                anchors.topMargin: 2
                anchors.bottom: parent.bottom
				text:		scan.firstTimeRun
				wrapMode: 	Text.Wrap
                lineHeight: 1.1

				font: commonFontStyles.standardCommonTextFont
                visible: scan.contextScan.IsNeverRun && !descriptionForFailedScan.visible;
			}
			Column
			{
				id: column
				objectName: "column"
				width:		parent.width
                spacing:	2
				visible:	!descriptionForNeverRanScan.visible && !descriptionForFailedScan.visible 

                Item
				{
					id: textTime
					objectName: "row"
                    height: childrenRect.height
                    width: parent.width
					Text
					{
                        id: textTimeText
						text: contextScan.IsRunning ? contextScan.Localize("RemainingTimeName") : 
						(contextScan.IsCompleted ?
						 contextScan.Localize("DurationSinceLastCompletedScanName") :
						 contextScan.Localize("DurationSinceLastInterruptedScanName"));
						font: commonFontStyles.standardCommonTextFont
					}
                    Widgets.Hyperlink
					{
                        anchors.left: textTimeText.right
                        anchors.right: parent.right
                        anchors.rightMargin: 10
                        objectName: "time"
                        text: contextScan.IsRunning ? contextScan.RemainingTime : contextScan.DurationSinceLastStop;
                        elide: Text.ElideRight
						onClicked: contextScan.ShowScanObjectReport();
					}
				}
				Row
				{
					id: textCount
					Text{text: contextScan.Localize("ScannedObjectCountName"); font: commonFontStyles.standardCommonTextFont}
					Text{text: contextScan.ScannedObjectCount; color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					id: threatsCountInfoVulnerability
					visible: checkScanTaskType("Vulnerability")
					Text{text: contextScan.Localize("VulnerabilityScan_CountName"); font: commonFontStyles.standardCommonTextFont}
					Text{text: contextScan.DetectedThreatCount ? contextScan.DetectedThreatCount :  contextScan.Localize("ObjectsAreAbsent");
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					visible: !threatsCountInfoVulnerability.visible
					Text{text: contextScan.Localize("DetectedThreatCountName"); font: commonFontStyles.standardCommonTextFont}
					Text{text: contextScan.DetectedThreatCount ? contextScan.DetectedThreatCount :  contextScan.Localize("ObjectsAreAbsent");
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}
				Row
				{
					visible: !threatsCountInfoVulnerability.visible && contextScan.DetectedThreatCount > 0
					Text{text: contextScan.Localize("NeutralizedThreatCountName"); font: commonFontStyles.standardCommonTextFont}
					Text{text: contextScan.NeutralizedThreatCount
					color: "Gray"; font: commonFontStyles.standardCommonTextFont}
				}				
			}
		}

		// FullScan specific
		Item
		{
			id:		actionOnTaskCompleted
			width:	parent.width
			anchors.top: commonText.bottom
            anchors.topMargin: 10
            visible: contextScan.IsRunning && checkScanTaskType("Full")
			Column
			{
				spacing: 1
				Text
				{
					id: 			actionOnTaskCompletedDescription
					text:			scan.contextScan.Localize("FullScan_ActionOnFinish")
					color:			"Black"
					wrapMode: 		Text.Wrap
					font:			commonFontStyles.standardCommonTextFont
				}
                Widgets.EnumCombo
	            {
	            	id:					actionOnTaskCompletedCombo
	            	objectName:			"ActionOnTaskCompleted"
					valueFont: 			commonFontStyles.standardCommonTextFont
					listFont:			commonFontStyles.standardListBoxFont

               		isBindingEnabled:		actionOnTaskCompleted.visible

	                enumPropertyHolder: contextScan
	                enumPropertyTitle:	"ActionOnTaskCompleted"
	                enumPropertyObject: contextScan.ActionOnTaskCompleted
	                onEnumPropertyChanged:
	                {
	                    if(checkScanTaskType("Full"))
	                        contextScan.ActionOnTaskCompleted = enumProperty;
		            }
		        }
	        }
		}
		// Vulnerability specific
		Item
		{
			objectName: "vulnerabilitiesList"
			width:			parent.width
            anchors.top: commonText.bottom
            anchors.topMargin: 10
            anchors.bottom: parent.bottom

            Widgets.GrayButton
			{
				objectName: "ShowVulnerabilitiesListButton"
				text: scan.contextScan.Localize("VulnerabilityScan_ShowObjectListButtonText")
				visible: !contextScan.IsRunning
				onClicked: context.ShowVulnerabilityList.Invoke()
			}

			visible: checkScanTaskType("Vulnerability") && !contextScan.IsNeverRun && !contextScan.IsFailed;
		}
	}
}
